<?php

namespace fazacrmclient;

/**
 * Gère les hooks, ainsi que la création du menu et des pages liées, côte wp-admin
 * @author lcoulomb 
 */
class Backend {

    private static $instance = null;

    /**
     * Configuration générale du menu côté backend
     */
    public function configure() {

        // On hook les fichier css et js
        add_action('admin_enqueue_scripts', array($this, 'enqueue_styles'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));

        // On créé les différents hooks afin de créer le menu et sous-menu du plugin dans le backoffice.
        add_action('admin_menu', function() {
            add_menu_page("FazaCRM", "FazaCRM", "manage_options", "fazacrm", array(\fazacrmclient\GeneralSettings::getInstance(), "getPageGeneralSettings"), plugins_url('assets/images/icon.png', dirname(__FILE__)));
            add_submenu_page("fazacrm", "Settings", __('Settings', 'fazacrmclient'), "manage_options", "fazacrm", array(\fazacrmclient\GeneralSettings::getInstance(), "getPageGeneralSettings"));
            add_submenu_page("fazacrm", "Email test", __('Configuration test', 'fazacrmclient'), "manage_options", "fazacrm_test_configuration", array(\fazacrmclient\GeneralSettings::getInstance(), "getPageConfigurationTest"));
            add_submenu_page('fazacrm', 'Documentation', 'Documentation', "manage_options", 'fazacrm_documentation', array(\fazacrmclient\GeneralSettings::getInstance(), "getPageDocumentation"));
        });

        //On définit un groupe d'option 'fazacrm_admin_settings' dans lequel on déclare deux champs
        add_action('admin_init', function() {
            register_setting('fazacrm_admin_settings', 'fazacrm_urlFazacrm');
            register_setting('fazacrm_admin_settings', 'fazacrm_keyPrivate');
        });

        //Hook qui ajoute le bouton 'settings' lors de l'activation du plugin sur la page plugin.php
        global $pagenow;

        $plugin_basename = dirname(dirname(plugin_basename(__FILE__))) . "/Plugin.php";

        if ($pagenow === 'plugins.php') {
            add_filter('plugin_action_links_' . $plugin_basename, array(\fazacrmclient\GeneralSettings::getInstance(), 'add_plugin_settings_link'), 10, 1);
        }
        //Hook qui permet d'afficher les messages de retour sur la configuration du plugin
        if ($pagenow . '?page=fazacrm' === 'admin.php?page=fazacrm') {
            add_action('admin_notices', array(\fazacrmclient\GeneralSettings::getInstance(), 'fazacrm_general_settings_notice'));
        }
    }

    /**
     * Retourne l'instance en cours de la classe Backend
     * et l'instancie si elle n'existe pas déjà
     * @return Backend
     */
    public static function getInstance() {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * Register the stylesheets for the admin area.
     */
    public function enqueue_styles() {
        wp_enqueue_style(\fazacrmclient\Plugin::$plugin_name, plugin_dir_url(__FILE__) . '../assets/admin.css', array(), \fazacrmclient\Plugin::$plugin_version, 'all');
    }

    /**
     * Register the JavaScript for the admin area.
     */
    public function enqueue_scripts() {
        wp_enqueue_script(\fazacrmclient\Plugin::$plugin_name, plugin_dir_url(__FILE__) . '../assets/admin.js', array('jquery'), \fazacrmclient\Plugin::$plugin_version, false);
    }

}
