<?php

namespace fazacrmclient;

/**
 * Permet de vérifier la bonne configuration du plugin
 * en liant le formulaire correspondant afin d'essayer d'échanger avec le
 * fazaCRM en entrant une adresse mail valide.
 * @author     Leo Coulomb
 */
class ConfigurationTest {

    private static $instance = null;

    public function __construct() {

        $newContact = new \fazacrmclient\Contact();
        if (filter_has_var(INPUT_POST, 'fazacrm_subscribe')) {
            $this->subscribe($newContact);
        }
        if (filter_has_var(INPUT_POST, 'fazacrm_unsubscribe')) {
            $this->unsubscribe($newContact);
        }
    }

    /**
     * Permet à lutilisateur de s'incrire aux newsletters et
     * gère les messages d'erreurs correspondants.
     * @param Contact $newContact
     */
    private function subscribe($newContact) {
        $sanitizeEmail = filter_input(INPUT_POST, 'fazacrm_test_email', FILTER_SANITIZE_EMAIL);
        if ($sanitizeEmail === '') {
            $args['class'] = 'error';
            $args ['message'] = 'This field cannot be empty.';
            $this->display_admin_notice($args);
            return;
        }
        $email = filter_var($sanitizeEmail, FILTER_VALIDATE_EMAIL);
        if ($email === false) {
            $args['class'] = 'error';
            $args ['message'] = ' is not a valid email.';
            $this->display_admin_notice($args);
            return;
        }

        $id = $newContact->fazaCRMContactSubscribe($email);
        $args = array();
        if ($id === false) {
            // $fazaCrmContact->getMessage() renvois une erreur lors 
            // d'une création ou d'une mise a jour de la fiche contact
            $message = $newContact->getMessage();
            $class = 'error';
        } else {
            // $fazaCrmContact->getMessage() permet de savoir s'il s'agit 
            // d'une création ou d'une mise a jour de la fiche contact
            $emailLink = ' <a href="mailto:' . $email . '">' . $email . '</a>';
            $accessContactRecord = ' <a href="http://fazacrm/ContactAdmin/' . $id . '/update" target="_blank">' . __('Click here to access the contact record.', 'fazacrmclient') . '</a>';
            $message = __($newContact->getMessage(), 'fazacrmclient') . ' ' . $emailLink . __(' is now subscribed to the FazaCrm\'s newsletters.', 'fazacrmclient') . $accessContactRecord;
            $class = 'success';
            $args['id'] = $id;
        }
        $args['class'] = $class;
        $args ['message'] = $message;
        $this->display_admin_notice($args);
    }

    /**
     * Permet à lutilisateur de se désinscrire des newsletters et
     * gère les messages d'erreurs correspondants.
     * @param Contact $newContact
     */
    private function unsubscribe($newContact) {

        // Même fonctionnement que la méthode subscribe mais pour la désinscription au FazaCRM

        $sanitizeEmail = filter_input(INPUT_POST, 'fazacrm_test_email', FILTER_SANITIZE_EMAIL);
        if ($sanitizeEmail === '') {
            $args['class'] = 'error';
            $args ['message'] = 'This field cannot be empty.';
            $this->display_admin_notice($args);
            return;
        }
        
        $email = filter_var($sanitizeEmail, FILTER_VALIDATE_EMAIL);

        if ($email === false) {
            $args['class'] = 'error';
            $args ['message'] = ' is not a valid email.';
            $this->display_admin_notice($args);
            return;
        }

        $id = $newContact->fazaCRMContactUnsubscribe($email);
        $args = array();
        if ($id === false) {
            $message = $newContact->getMessage();
            $class = 'error';
        } else {
            $emailLink = ' <a href="mailto:' . $email . '">' . $email . '</a>';
            $accessContactRecord = ' <a href="http://fazacrm/ContactAdmin/' . $id . '/update" target="_blank">' . __('Click here to access the contact record.', 'fazacrmclient') . '</a>';
            $message = __($newContact->getMessage(), 'fazacrmclient') . $emailLink . __(' is now unsubscribed to the FazaCrm\'s newsletters.', 'fazacrmclient') . $accessContactRecord;
            $class = 'warning';
            $args['id'] = $id;
        }
        $args['class'] = $class;
        $args ['message'] = $message;
        $this->display_admin_notice($args);
    }

    /**
     * Récupère la classe CSS et le message à afficher dans le backoffice 
     * au retour de la communiquation avec l'API du fazaCRM, traite les informations
     * et affiche celles souhaitées
     * @param array $args Contient les données à utiliser pour l'affichage de l'admin notice
     */
    public function display_admin_notice($args) {

        $email = '';
        if ($args['message'] === ' is not a valid email.') {
            if (filter_has_var(INPUT_POST, 'fazacrm_test_email')) {
                $email = filter_input(INPUT_POST, 'fazacrm_test_email', FILTER_SANITIZE_EMAIL);
            }
        }

        printf('<div class="%1$s"><p>%2$s%3$s</p></div>', esc_attr('notice notice-' . $args['class'] . ' is-dismissible'), $email, __($args['message'], 'fazacrmclient'));
    }

    /**
     * Retourne l'instance en cours de la classe ConfigurationTest
     * et l'instancie si elle n'existe pas déjà
     * @return ConfigurationTest $instance
     */
    public static function getInstance() {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

}
