<?php

namespace fazacrmclient;

/**
 * Gère la communication entre l'API du FazaCRM et le plugin avec cURL pour paramètrer les entêtes
 * et contenues des requêtes HTTP afin de récupérer leurs réponses.
 * @author     Leo Coulomb
 */
class Contact extends \fazacrmclient\fazaCRMRESTClient {

    /**
     * Récupère l'URL du FazaCRM, sa clé API et défini sa version sur 1.1
     */
    public function __construct() {
        $crm_uri = get_option('fazacrm_urlFazacrm', '');
        $apiVersion = 1.1;
        $apiKey = get_option('fazacrm_keyPrivate', '');

        parent::__construct($crm_uri, $apiVersion, $apiKey);
    }

    /**
     * Retourne la valeur de la propriété message.
     * @return string 
     */
    public function getMessage() {
        return parent::getMessage();
    }

    /**
     * On demande de créer le contact (si celui existe déjà il sera mis à jour)
     * Et on l'abonne aux newsletters Fazaé
     * @param string $email
     * @return int|bool L'ID du contact s'il est crée/mis à jour et FALSE si une erreur se produit
     */
    public function fazaCRMContactSubscribe($email) {
        $contact_data = array(
            'email' => $email,
            'abonne' => true
        );
        $id = parent::contactCreate($contact_data);
        return $id;
    }

    /**
     * On demande de créer le contact (si celui existe déjà il sera mis à jour)
     * Et on le désabonne des newsletters Fazae
     * @param string $email
     * @return int|bool L'ID du contact s'il est crée/mis à jour et FALSE si une erreur se produit
     */
    public function fazaCRMContactUnsubscribe($email) {
        $contact_data = array(
            'email' => $email,
            'abonne' => false
        );
        $id = parent::contactCreate($contact_data);
        return $id;
    }

    /**
     * Vérfie l'accès à l'API en testant la clé privée ainsi que la validité de l'URL
     * @return boolean
     */
    public function apiAccess() {

        parent::zendInit('tags?limit=1');
        if ($this->client === null) {
            return;
        }
        try {
            $this->client->send();
        } catch (\Exception $exc) {
            $this->logError("apiAccess - " . $exc->getMessage());
        }
        $response = $this->client->getResponse();
        if ($response->getStatusCode() === 200) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Met en forme les logs, et les écris dans wp-content/debug.log
     * Ajouter les lignes suivantes dans wp-config.php pour activer les logs.
     * define( 'WP_DEBUG', true );
     * define('WP_DEBUG_LOG', true);
     * define( 'WP_DEBUG_DISPLAY', false );
     * @param string $message Le message à ecrire dans les logs
     */
    public function log($message) {
        if (is_array($message) || is_object($message)) {
            error_log(" - " . print_r($message, true));
        } else {
            error_log(" - " . $message);
        }
    }

    /**
     * Override de la méthode parent, nous n'avons pas besoin d'un dossier 
     * de log propre ici, tout est insérer dans le fichier debug.log de WP
     */
    public function logInit() {
        return;
    }

}
