<?php

namespace fazacrmclient;

/**
 * Gère la configuration de la page options-settings du plugin.
 * Récupère les valeurs des champs 'options' et 
 * affiche des settings_error spécifiques à la configuration
 * générale
 * @author     Leo Coulomb
 */
class GeneralSettings {

    private static $instance = null;
    public static $KeyPrivate = '';
    public static $UrlFazacrm = '';
    public static $apiStatusMessage = '';
    public static $apiStatusClass = '';

    public function __construct() {

        self::$KeyPrivate = esc_html(get_option('fazacrm_keyPrivate'));
        self::$UrlFazacrm = esc_html(get_option('fazacrm_urlFazacrm'));
        $this->checkApiStatus();
    }

    /**
     * Vérfie la configuration du plugin et renvoie un message
     * via une admin_notice
     */
    public function fazacrm_general_settings_notice() {

        $currentURI = filter_input(INPUT_SERVER, 'REQUEST_URI', FILTER_SANITIZE_URL);
        //Si on se trouve sur la page de settings générale avec ou sans 
        //enregistrement des paramètres 
        if ($currentURI == '/wp-admin/admin.php?page=fazacrm' ||
                $currentURI == '/wp-admin/admin.php?page=fazacrm&settings-updated=true') {
            $fazacrmContact = new \fazacrmclient\Contact();
            if (!$fazacrmContact->isValidUrl(self::$UrlFazacrm)) {
                $type = 'error';
                $message = 'The FazaCRM\'s URL is not a valid URL, please check your settings.';
            }
            if (empty(self::$KeyPrivate) || empty(self::$UrlFazacrm)) {
                $type = 'error';
                $message = 'You must complete the following fields to use this plugin.';
            }
            if (isset($type) || isset($message)) {
                add_settings_error(
                        'fazacrm_admin_settings_notice', esc_attr('settings_updated'), __($message, 'fazacrmclient'), $type
                );
            }
        }
    }

    /**
     * Si avec la clé privée et l'URL spécifié on arrive à joindre le FazaCRM
     * On affiche un message CONNECTED et NOT CONNECTED dans le cas contraire
     */
    public function checkApiStatus() {
        $newContact = new \fazacrmclient\Contact();
        if ($newContact->apiAccess() === true) {
            self::$apiStatusClass = 'Connected';
            self::$apiStatusMessage = 'CONNECTED';
        } else {
            self::$apiStatusClass = 'notConnected';
            self::$apiStatusMessage = 'NOT CONNECTED';
        }
    }

    /**
     * Lie la vue Configuration.php au lien de menu spécifié 
     */
    public function getPageGeneralSettings() {
        include __DIR__ . '/../views/GeneralSettings.php';
        \fazacrmclient\GeneralSettings::getInstance();
    }

    /**
     * Lie la vue ConfigurationTest.php au lien de menu spécifié
     */
    public function getPageConfigurationTest() {
        include __DIR__ . '/../views/ConfigurationTest.php';
        \fazacrmclient\ConfigurationTest::getInstance();
    }

    /**
     * Lie la vue Documentation.php au lien de menu spécifié
     */
    public function getPageDocumentation() {
        include __DIR__ . "/../views/Documentation.php";
    }

    /**
     * Ajoute le lien 'settings' sur la page plugin.php
     * @param array $links
     * @return array
     */
    public function add_plugin_settings_link($links) {
        $settings_link = '<a href="' . admin_url('admin.php?page=fazacrm') . '">' . __('Settings', 'fazacrm') . '</a>';
        array_unshift($links, $settings_link);
        return $links;
    }

    /**
     * Retourne l'instance en cours de la classe GeneralSettings
     * et l'instancie si elle n'existe pas déjà
     * @return GeneralSettings $insatnce
     */
    public static function getInstance() {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

}
